@@ -14,7 +14,7 @@
 #'
 #' @param x A vector
 #'
-#' @return A logical vector of same size as x which is true where x is true (\code{rlang::\link{as_logical}}) and not NA
+#' @return A logical vector of same size as x which is true where x is true (\code{\link[rlang]{as_logical}}) and not NA
 #' @export
 are_true <- function(x)
 {
@@ -61,11 +61,14 @@ compareNA <- equal_including_na
 any_or_all_na <- function(...)
 {
 
-  if (all(are_na(dots_list(...))))
+  if (all(map_lgl(list2(...), are_na)))
   {
-    return(NA)
+    na_lgl
+  }
+  else
+  {
+    any(..., na.rm = T)
   }
-  return(any(..., na.rm = T))
 }
 
 anyOrAllNA <- any_or_all_na
@@ -78,11 +81,14 @@ anyOrAllNA <- any_or_all_na
 #' @export
 all_or_all_na <- function(...)
 {
-  if (all(are_na(dots_list(...))))
+  if (all(map_lgl(list2(...), are_na)))
   {
-    return(NA)
+    na_lgl
+  }
+  else
+  {
+    all(..., na.rm = T)
   }
-  return(all(..., na.rm = T))
 }
 
 allOrAllNA <- all_or_all_na
@@ -254,7 +260,7 @@ which_non_na <- function(...)
 #' Row-wise first value that is not NA
 #'
 #' @param .tbl A data frame
-#' @param ... A column selection, as for \code{dplyr::\link{select}}
+#' @param ... A column selection, as for \code{\link[dplyr]{select}}
 #'
 #' @return A vector of length nrow(.tbl) containing the first found non-na value
 #' @export
@@ -271,7 +277,7 @@ first_non_nas_at <- function(.tbl, ...)
 #' Row-wise first index of column that is not NA
 #'
 #' @param .tbl A data frame
-#' @param ... A column selection, as for \code{dplyr::\link{select}}
+#' @param ... A column selection, as for \code{\link[dplyr]{select}}
 #'
 #' @return A numeric vector of length nrow(.tbl) containing the index of the first found non-na value in the given columns.
 #'    Possible values are NA (all values in that row are NA), and 1 ... number of columns in selection
